#ifndef	cmlmmoderate_h
#define	cmlmmoderate_h

/*
** Copyright 2000 Double Precision, Inc.
** See COPYING for distribution information.
*/

static const char cmlmmoderate_h_rcsid[]="$Id: cmlmmoderate.h,v 1.5 2007/03/01 04:32:03 mrsam Exp $";

#include	"config.h"
#include	<iostream>

int sendinitmod(afxipipestream &, const char *, const char *);
int cmdmoderate();
int postmsg(std::istream &, int (*)(std::istream &, std::ostream &));

#endif
